@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Advanced interpolation engine for Alien builds
-our $VERSION = '2.06_01'; # TRIAL VERSION
+our $VERSION = '2.07_01'; # TRIAL VERSION
 $VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 
@@ -170,7 +170,8 @@ sub requires
 {
   my($self, $string) = @_;
   map {
-    $self->{helper}->{$_}->require
+    my $helper = $self->{helper}->{$_};
+    $helper ? $helper->require : ();
   } $string =~ m{(?<!\%)\%\{([a-zA-Z_][a-zA-Z_0-9]+)\}}g;
 }
 
@@ -249,7 +250,7 @@ Alien::Build::Interpolate - Advanced interpolation engine for Alien builds
 
 =head1 VERSION
 
-version 2.06_01
+version 2.07_01
 
 =head1 CONSTRUCTOR
 
